@@ -5,6 +5,7 @@
 #' @param data A data.frame or data.table
 #' @param colnames Character vector with column names corresponding to columns in \emph{data}
 #' @param only_colnames Assert that the only columns in the data object should be those in \emph{colnames}. Default = T.
+#' @param quiet Do you want to suppress the printed message when a test is passed? Default = F.
 
 #' @return Throws error if test is violated.
 #' @export
@@ -13,7 +14,7 @@
 #' assert_colnames(CO2, c("Plant","Type","Treatment","conc","uptake"))
 #' assert_colnames(CO2, c("Plant","Type"), only_colnames=FALSE)
 
-assert_colnames <- function(data, colnames, only_colnames=TRUE) {
+assert_colnames <- function(data, colnames, only_colnames=TRUE, quiet=FALSE) {
   # Do all specified colnames exist in dataframe?
     non_df_cols <- colnames[!colnames %in% colnames(data)]
   
@@ -32,5 +33,8 @@ assert_colnames <- function(data, colnames, only_colnames=TRUE) {
     stop(paste0("These columns exist in your dataframe but not in colnames: ",
                 paste(non_colname_cols, collapse=" ")))
   }
-  print("All column names present")
+    
+  if(!quiet) {
+    print("All column names present")
+  }
 }
